==> kenry-validator-1.0.3.tgz: package/.eslintrc.js <==
module.exports = {
  root: true,
  parser: 'babel-eslint',
  env: {
      browser: true,
      commonjs: true,
      es6: true,
      jquery: true,
      node: true
  },
  extends: 'standard',
  // required to lint *.vue files
  rules: {
      'indent': ['error', 4],
      'semi': ['error', 'always'],
      'require-jsdoc': 'off',
      'valid-jsdoc': 'off',
      'max-len': 'off',
      'no-debugger': 'off',
      'no-console': 'off',
      'curly': 'off',
      'arrow-parens': 'off',
      'comma-dangle': 'off',
      'linebreak-style': 'off',
      'no-useless-constructor': 'off',
      'no-unused-vars': 'off',
      'yoda': 'error',
      'space-infix-ops': 'error',
      'switch-colon-spacing': ['error', {'before': false, 'after': true}],
      'key-spacing': ['error', {'beforeColon': false, 'afterColon': true}],
      'eqeqeq': ['error', 'always', {'null': 'ignore'}],
      'no-multiple-empty-lines': ['error', { 'max': 1, 'maxEOF': 1 }],
      'keyword-spacing': ['error', {'before': true, 'after': true}],
      'arrow-spacing': ['error', {'before': true, 'after': true}],
      'brace-style': ['error', 'stroustrup'],
      'object-curly-spacing': ['error', 'never', {'objectsInObjects': false, 'arraysInObjects': false}],
      'space-before-function-paren': ['error', {
          'anonymous': 'never',
          'named': 'never',
          'asyncArrow': 'always'
      }]
  },
  parserOptions: {
      ecmaVersion: 7,
      sourceType: 'module',
      ecmaFeatures: {}
  },
  globals: {}
}

==> kenry-validator-1.1.3.tgz: package/.eslintrc.js <==
module.exports = {
  root: true,
  parser: 'babel-eslint',
  env: {
      browser: true,
      commonjs: true,
      es6: true,
      jquery: true,
      node: true
  },
  extends: 'standard',
  // required to lint *.vue files
  rules: {
      'indent': ['error', 4],
      'semi': ['error', 'always'],
      'require-jsdoc': 'off',
      'valid-jsdoc': 'off',
      'max-len': 'off',
      'no-debugger': 'error',
      'no-console': 'off',
      'curly': 'off',
      'arrow-parens': 'off',
      'comma-dangle': 'off',
      'linebreak-style': 'off',
      'no-useless-constructor': 'off',
      'no-unused-vars': 'off',
      'yoda': 'error',
      'space-infix-ops': 'error',
      'switch-colon-spacing': ['error', {'before': false, 'after': true}],
      'key-spacing': ['error', {'beforeColon': false, 'afterColon': true}],
      'eqeqeq': ['error', 'always', {'null': 'ignore'}],
      'no-multiple-empty-lines': ['error', { 'max': 1, 'maxEOF': 1 }],
      'keyword-spacing': ['error', {'before': true, 'after': true}],
      'arrow-spacing': ['error', {'before': true, 'after': true}],
      'brace-style': ['error', 'stroustrup'],
      'object-curly-spacing': ['error', 'never', {'objectsInObjects': false, 'arraysInObjects': false}],
      'space-before-function-paren': ['error', {
          'anonymous': 'never',
          'named': 'never',
          'asyncArrow': 'always'
      }]
  },
  parserOptions: {
      ecmaVersion: 7,
      sourceType: 'module',
      ecmaFeatures: {}
  },
  globals: {}
}
